# Description

pfinsim stands for **p**ersonal **fin**ance **s**imulation.

Its goal is to allow for users to easily investigate the effect of taxes and investing on their personal financial situation. Use cases can be found on [the author's blog](https://xgerrmann.github.io/geld-en-zo/).

As of writing this project is focused on the Dutch tax system. Efforts to extend towards other countries is highly appreciated.

The following is currently supported

* Investing
* Real estate
  * Mortgages
* Taxes
  * Tax credits
  * Income taxes
* Jobs
  * Monthly income
  * Holiday allowance



This project on [Github](https://github.com/xgerrmann/pfinsim)



## Log

* Uploaded to pypi as `pfinsim` 2020-12-26

